/*
  Authors : initappz (Rahul Jograna)
  Website : https://initappz.com/
  App Name : Handy Service Full App Flutter V3
  This App Template Source code is licensed as per the
  terms found in the Website https://initappz.com/license
  Copyright and Good Faith Purchasers © 2024-present initappz.
*/
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:freelancer/app/controller/chat_controller.dart';
import 'package:freelancer/app/util/theme.dart';

class ChatScreen extends StatefulWidget {
  const ChatScreen({Key? key}) : super(key: key);

  @override
  State<ChatScreen> createState() => _ChatScreenState();
}

class _ChatScreenState extends State<ChatScreen> {
  @override
  Widget build(BuildContext context) {
    return GetBuilder<ChatController>(
      builder: (value) {
        return Scaffold(
          backgroundColor: ThemeProvider.backgroundColor,
          appBar: AppBar(
            backgroundColor: ThemeProvider.appColor,
            iconTheme: const IconThemeData(color: ThemeProvider.whiteColor),
            elevation: 0,
            centerTitle: true,
            title: Text(value.title, style: ThemeProvider.titleStyle),
          ),
          body: value.apiCalled == false
              ? const Center(child: CircularProgressIndicator(color: ThemeProvider.appColor))
              : SingleChildScrollView(
                  controller: value.scrollController,
                  padding: const EdgeInsets.all(16),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: List.generate(
                      value.chatList.length,
                      (index) {
                        return value.chatList[index].senderId.toString() != value.uid.toString()
                            ? Container(
                                margin: const EdgeInsets.only(bottom: 16),
                                width: MediaQuery.of(context).size.width - 120,
                                child: Row(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: <Widget>[
                                    Flexible(
                                      child: Column(
                                        mainAxisAlignment: MainAxisAlignment.start,
                                        crossAxisAlignment: CrossAxisAlignment.start,
                                        children: [
                                          Container(
                                            padding: const EdgeInsets.symmetric(horizontal: 15, vertical: 10),
                                            decoration: BoxDecoration(
                                              color: ThemeProvider.greyColor.shade300,
                                              borderRadius: const BorderRadius.only(
                                                topLeft: Radius.circular(30),
                                                topRight: Radius.circular(30),
                                                bottomRight: Radius.circular(30),
                                                bottomLeft: Radius.circular(30),
                                              ),
                                            ),
                                            child: Text(value.chatList[index].message.toString(), style: const TextStyle(fontSize: 14)),
                                          ),
                                        ],
                                      ),
                                    )
                                  ],
                                ),
                              )
                            : Column(
                                mainAxisAlignment: MainAxisAlignment.end,
                                crossAxisAlignment: CrossAxisAlignment.end,
                                children: [
                                  Row(
                                    mainAxisAlignment: MainAxisAlignment.end,
                                    children: <Widget>[
                                      Container(
                                        margin: const EdgeInsets.only(bottom: 16),
                                        width: MediaQuery.of(context).size.width - 120,
                                        child: Row(
                                          mainAxisAlignment: MainAxisAlignment.end,
                                          crossAxisAlignment: CrossAxisAlignment.start,
                                          children: <Widget>[
                                            Flexible(
                                              child: Column(
                                                mainAxisAlignment: MainAxisAlignment.end,
                                                crossAxisAlignment: CrossAxisAlignment.end,
                                                children: [
                                                  Container(
                                                    margin: const EdgeInsets.only(right: 10),
                                                    padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 15),
                                                    decoration: const BoxDecoration(
                                                      color: ThemeProvider.appColor,
                                                      borderRadius: BorderRadius.only(
                                                        topLeft: Radius.circular(30),
                                                        topRight: Radius.circular(30),
                                                        bottomLeft: Radius.circular(30),
                                                        bottomRight: Radius.circular(30),
                                                      ),
                                                    ),
                                                    child: Text(value.chatList[index].message.toString(), style: const TextStyle(color: ThemeProvider.whiteColor, fontSize: 14)),
                                                  ),
                                                ],
                                              ),
                                            ),
                                          ],
                                        ),
                                      ),
                                    ],
                                  ),
                                ],
                              );
                      },
                    ),
                  ),
                ),
          bottomNavigationBar: SingleChildScrollView(
            reverse: true,
            padding: EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
            child: Container(
              height: 50,
              margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 10),
              child: Row(
                children: <Widget>[
                  Expanded(
                    child: Container(
                      padding: const EdgeInsets.symmetric(horizontal: 10),
                      decoration: BoxDecoration(borderRadius: const BorderRadius.all(Radius.circular(25)), color: ThemeProvider.greyColor.shade300),
                      child: TextField(controller: value.message, keyboardType: TextInputType.text, decoration: InputDecoration(border: InputBorder.none, hintText: 'Message...'.tr)),
                    ),
                  ),
                  const SizedBox(width: 20),
                  InkWell(
                    onTap: () => value.sendMessage(),
                    child: Container(
                      height: 50,
                      width: 50,
                      decoration: const BoxDecoration(color: ThemeProvider.appColor, borderRadius: BorderRadius.all(Radius.circular(50))),
                      child: const Icon(Icons.near_me, color: ThemeProvider.whiteColor),
                    ),
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
